Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=loadtestservice.azure.upbound.io +versionName=v1beta1
Index ¶
- Constants
- Variables
- type EncryptionInitParameters
- type EncryptionObservation
- type EncryptionParameters
- type IdentityInitParameters
- type IdentityObservation
- type IdentityParameters
- type LoadTest
- func (tr *LoadTest) ConvertFrom(srcRaw conversion.Hub) error
- func (tr *LoadTest) ConvertTo(dstRaw conversion.Hub) error
- func (in *LoadTest) DeepCopy() *LoadTest
- func (in *LoadTest) DeepCopyInto(out *LoadTest)
- func (in *LoadTest) DeepCopyObject() runtime.Object
- func (mg *LoadTest) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *LoadTest) GetConnectionDetailsMapping() map[string]string
- func (mg *LoadTest) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *LoadTest) GetID() string
- func (tr *LoadTest) GetInitParameters() (map[string]any, error)
- func (mg *LoadTest) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *LoadTest) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *LoadTest) GetObservation() (map[string]any, error)
- func (tr *LoadTest) GetParameters() (map[string]any, error)
- func (mg *LoadTest) GetProviderConfigReference() *xpv1.Reference
- func (mg *LoadTest) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *LoadTest) GetTerraformResourceType() string
- func (tr *LoadTest) GetTerraformSchemaVersion() int
- func (mg *LoadTest) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *LoadTest) LateInitialize(attrs []byte) (bool, error)
- func (mg *LoadTest) ResolveReferences(ctx context.Context, c client.Reader) error
- func (mg *LoadTest) SetConditions(c ...xpv1.Condition)
- func (mg *LoadTest) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *LoadTest) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *LoadTest) SetObservation(obs map[string]any) error
- func (tr *LoadTest) SetParameters(params map[string]any) error
- func (mg *LoadTest) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *LoadTest) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *LoadTest) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type LoadTestIdentityInitParameters
- type LoadTestIdentityObservation
- type LoadTestIdentityParameters
- type LoadTestInitParameters
- type LoadTestList
- type LoadTestObservation
- type LoadTestParameters
- type LoadTestSpec
- type LoadTestStatus
Constants ¶
const ( CRDGroup = "loadtestservice.azure.upbound.io" CRDVersion = "v1beta1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( LoadTest_Kind = "LoadTest" LoadTest_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: LoadTest_Kind}.String() LoadTest_KindAPIVersion = LoadTest_Kind + "." + CRDGroupVersion.String() LoadTest_GroupVersionKind = CRDGroupVersion.WithKind(LoadTest_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type EncryptionInitParameters ¶ added in v1.7.0
type EncryptionInitParameters struct {
// An identity block as defined below. Changing this forces a new Load Test to be created.
Identity []IdentityInitParameters `json:"identity,omitempty" tf:"identity,omitempty"`
// The URI specifying the Key vault and key to be used to encrypt data in this resource. The URI should include the key version. Changing this forces a new Load Test to be created.
KeyURL *string `json:"keyUrl,omitempty" tf:"key_url,omitempty"`
}
func (*EncryptionInitParameters) DeepCopy ¶ added in v1.7.0
func (in *EncryptionInitParameters) DeepCopy() *EncryptionInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EncryptionInitParameters.
func (*EncryptionInitParameters) DeepCopyInto ¶ added in v1.7.0
func (in *EncryptionInitParameters) DeepCopyInto(out *EncryptionInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EncryptionObservation ¶ added in v1.7.0
type EncryptionObservation struct {
// An identity block as defined below. Changing this forces a new Load Test to be created.
Identity *IdentityObservation `json:"identity,omitempty" tf:"identity,omitempty"`
// The URI specifying the Key vault and key to be used to encrypt data in this resource. The URI should include the key version. Changing this forces a new Load Test to be created.
KeyURL *string `json:"keyUrl,omitempty" tf:"key_url,omitempty"`
}
func (*EncryptionObservation) DeepCopy ¶ added in v1.7.0
func (in *EncryptionObservation) DeepCopy() *EncryptionObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EncryptionObservation.
func (*EncryptionObservation) DeepCopyInto ¶ added in v1.7.0
func (in *EncryptionObservation) DeepCopyInto(out *EncryptionObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EncryptionParameters ¶ added in v1.7.0
type EncryptionParameters struct {
// An identity block as defined below. Changing this forces a new Load Test to be created.
// +kubebuilder:validation:Optional
Identity *IdentityParameters `json:"identity" tf:"identity,omitempty"`
// The URI specifying the Key vault and key to be used to encrypt data in this resource. The URI should include the key version. Changing this forces a new Load Test to be created.
// +kubebuilder:validation:Optional
KeyURL *string `json:"keyUrl" tf:"key_url,omitempty"`
}
func (*EncryptionParameters) DeepCopy ¶ added in v1.7.0
func (in *EncryptionParameters) DeepCopy() *EncryptionParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EncryptionParameters.
func (*EncryptionParameters) DeepCopyInto ¶ added in v1.7.0
func (in *EncryptionParameters) DeepCopyInto(out *EncryptionParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IdentityInitParameters ¶
type IdentityInitParameters struct {
// The User Assigned Identity ID that should be assigned to this Load Test Encryption. Changing this forces a new Load Test to be created.
IdentityID *string `json:"identityId,omitempty" tf:"identity_id,omitempty"`
// Specifies the type of Managed Identity that should be assigned to this Load Test. Possible values are SystemAssigned, SystemAssigned, UserAssigned and UserAssigned.
Type *string `json:"type,omitempty" tf:"type,omitempty"`
}
func (*IdentityInitParameters) DeepCopy ¶
func (in *IdentityInitParameters) DeepCopy() *IdentityInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IdentityInitParameters.
func (*IdentityInitParameters) DeepCopyInto ¶
func (in *IdentityInitParameters) DeepCopyInto(out *IdentityInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IdentityObservation ¶
type IdentityObservation struct {
// The User Assigned Identity ID that should be assigned to this Load Test Encryption. Changing this forces a new Load Test to be created.
IdentityID *string `json:"identityId,omitempty" tf:"identity_id,omitempty"`
// Specifies the type of Managed Identity that should be assigned to this Load Test. Possible values are SystemAssigned, SystemAssigned, UserAssigned and UserAssigned.
Type *string `json:"type,omitempty" tf:"type,omitempty"`
}
func (*IdentityObservation) DeepCopy ¶
func (in *IdentityObservation) DeepCopy() *IdentityObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IdentityObservation.
func (*IdentityObservation) DeepCopyInto ¶
func (in *IdentityObservation) DeepCopyInto(out *IdentityObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IdentityParameters ¶
type IdentityParameters struct {
// The User Assigned Identity ID that should be assigned to this Load Test Encryption. Changing this forces a new Load Test to be created.
// +kubebuilder:validation:Optional
IdentityID *string `json:"identityId" tf:"identity_id,omitempty"`
// Specifies the type of Managed Identity that should be assigned to this Load Test. Possible values are SystemAssigned, SystemAssigned, UserAssigned and UserAssigned.
// +kubebuilder:validation:Optional
Type *string `json:"type" tf:"type,omitempty"`
}
func (*IdentityParameters) DeepCopy ¶
func (in *IdentityParameters) DeepCopy() *IdentityParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IdentityParameters.
func (*IdentityParameters) DeepCopyInto ¶
func (in *IdentityParameters) DeepCopyInto(out *IdentityParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadTest ¶
type LoadTest struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.location) || (has(self.initProvider) && has(self.initProvider.location))",message="spec.forProvider.location is a required parameter"
Spec LoadTestSpec `json:"spec"`
Status LoadTestStatus `json:"status,omitempty"`
}
LoadTest is the Schema for the LoadTests API. Manages a Load Test. +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,azure}
func (*LoadTest) ConvertFrom ¶ added in v1.2.0
func (tr *LoadTest) ConvertFrom(srcRaw conversion.Hub) error
ConvertFrom converts from the hub type to the LoadTest type.
func (*LoadTest) ConvertTo ¶ added in v1.2.0
func (tr *LoadTest) ConvertTo(dstRaw conversion.Hub) error
ConvertTo converts this LoadTest to the hub type.
func (*LoadTest) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTest.
func (*LoadTest) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LoadTest) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*LoadTest) GetCondition ¶
func (mg *LoadTest) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this LoadTest.
func (*LoadTest) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this LoadTest
func (*LoadTest) GetDeletionPolicy ¶
func (mg *LoadTest) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this LoadTest.
func (*LoadTest) GetInitParameters ¶
GetInitParameters of this LoadTest
func (*LoadTest) GetManagementPolicies ¶
func (mg *LoadTest) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this LoadTest.
func (*LoadTest) GetMergedParameters ¶ added in v0.40.0
GetInitParameters of this LoadTest
func (*LoadTest) GetObservation ¶
GetObservation of this LoadTest
func (*LoadTest) GetParameters ¶
GetParameters of this LoadTest
func (*LoadTest) GetProviderConfigReference ¶
GetProviderConfigReference of this LoadTest.
func (*LoadTest) GetPublishConnectionDetailsTo ¶
func (mg *LoadTest) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this LoadTest.
func (*LoadTest) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this LoadTest
func (*LoadTest) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*LoadTest) GetWriteConnectionSecretToReference ¶
func (mg *LoadTest) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this LoadTest.
func (*LoadTest) LateInitialize ¶
LateInitialize this LoadTest using its observed tfState. returns True if there are any spec changes for the resource.
func (*LoadTest) ResolveReferences ¶
func (*LoadTest) SetConditions ¶
SetConditions of this LoadTest.
func (*LoadTest) SetDeletionPolicy ¶
func (mg *LoadTest) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this LoadTest.
func (*LoadTest) SetManagementPolicies ¶
func (mg *LoadTest) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this LoadTest.
func (*LoadTest) SetObservation ¶
SetObservation for this LoadTest
func (*LoadTest) SetParameters ¶
SetParameters for this LoadTest
func (*LoadTest) SetProviderConfigReference ¶
SetProviderConfigReference of this LoadTest.
func (*LoadTest) SetPublishConnectionDetailsTo ¶
func (mg *LoadTest) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this LoadTest.
func (*LoadTest) SetWriteConnectionSecretToReference ¶
func (mg *LoadTest) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this LoadTest.
type LoadTestIdentityInitParameters ¶ added in v1.7.0
type LoadTestIdentityInitParameters struct {
// A list of the User Assigned Identity IDs that should be assigned to this Load Test.
// +listType=set
IdentityIds []*string `json:"identityIds,omitempty" tf:"identity_ids,omitempty"`
// Specifies the type of Managed Identity that should be assigned to this Load Test. Possible values are SystemAssigned, SystemAssigned, UserAssigned and UserAssigned.
Type *string `json:"type,omitempty" tf:"type,omitempty"`
}
func (*LoadTestIdentityInitParameters) DeepCopy ¶ added in v1.7.0
func (in *LoadTestIdentityInitParameters) DeepCopy() *LoadTestIdentityInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestIdentityInitParameters.
func (*LoadTestIdentityInitParameters) DeepCopyInto ¶ added in v1.7.0
func (in *LoadTestIdentityInitParameters) DeepCopyInto(out *LoadTestIdentityInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadTestIdentityObservation ¶ added in v1.7.0
type LoadTestIdentityObservation struct {
// A list of the User Assigned Identity IDs that should be assigned to this Load Test.
// +listType=set
IdentityIds []*string `json:"identityIds,omitempty" tf:"identity_ids,omitempty"`
// The Principal ID for the System-Assigned Managed Identity assigned to this Load Test.
PrincipalID *string `json:"principalId,omitempty" tf:"principal_id,omitempty"`
// The Tenant ID for the System-Assigned Managed Identity assigned to this Load Test.
TenantID *string `json:"tenantId,omitempty" tf:"tenant_id,omitempty"`
// Specifies the type of Managed Identity that should be assigned to this Load Test. Possible values are SystemAssigned, SystemAssigned, UserAssigned and UserAssigned.
Type *string `json:"type,omitempty" tf:"type,omitempty"`
}
func (*LoadTestIdentityObservation) DeepCopy ¶ added in v1.7.0
func (in *LoadTestIdentityObservation) DeepCopy() *LoadTestIdentityObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestIdentityObservation.
func (*LoadTestIdentityObservation) DeepCopyInto ¶ added in v1.7.0
func (in *LoadTestIdentityObservation) DeepCopyInto(out *LoadTestIdentityObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadTestIdentityParameters ¶ added in v1.7.0
type LoadTestIdentityParameters struct {
// A list of the User Assigned Identity IDs that should be assigned to this Load Test.
// +kubebuilder:validation:Optional
// +listType=set
IdentityIds []*string `json:"identityIds,omitempty" tf:"identity_ids,omitempty"`
// Specifies the type of Managed Identity that should be assigned to this Load Test. Possible values are SystemAssigned, SystemAssigned, UserAssigned and UserAssigned.
// +kubebuilder:validation:Optional
Type *string `json:"type" tf:"type,omitempty"`
}
func (*LoadTestIdentityParameters) DeepCopy ¶ added in v1.7.0
func (in *LoadTestIdentityParameters) DeepCopy() *LoadTestIdentityParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestIdentityParameters.
func (*LoadTestIdentityParameters) DeepCopyInto ¶ added in v1.7.0
func (in *LoadTestIdentityParameters) DeepCopyInto(out *LoadTestIdentityParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadTestInitParameters ¶
type LoadTestInitParameters struct {
// Description of the resource. Changing this forces a new Load Test to be created.
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// An encryption block as defined below. Changing this forces a new Load Test to be created.
Encryption []EncryptionInitParameters `json:"encryption,omitempty" tf:"encryption,omitempty"`
// An identity block as defined below. Specifies the Managed Identity which should be assigned to this Load Test.
Identity []LoadTestIdentityInitParameters `json:"identity,omitempty" tf:"identity,omitempty"`
// The Azure Region where the Load Test should exist. Changing this forces a new Load Test to be created.
Location *string `json:"location,omitempty" tf:"location,omitempty"`
// A mapping of tags which should be assigned to the Load Test.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*LoadTestInitParameters) DeepCopy ¶
func (in *LoadTestInitParameters) DeepCopy() *LoadTestInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestInitParameters.
func (*LoadTestInitParameters) DeepCopyInto ¶
func (in *LoadTestInitParameters) DeepCopyInto(out *LoadTestInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadTestList ¶
type LoadTestList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []LoadTest `json:"items"`
}
LoadTestList contains a list of LoadTests
func (*LoadTestList) DeepCopy ¶
func (in *LoadTestList) DeepCopy() *LoadTestList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestList.
func (*LoadTestList) DeepCopyInto ¶
func (in *LoadTestList) DeepCopyInto(out *LoadTestList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LoadTestList) DeepCopyObject ¶
func (in *LoadTestList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*LoadTestList) GetItems ¶
func (l *LoadTestList) GetItems() []resource.Managed
GetItems of this LoadTestList.
type LoadTestObservation ¶
type LoadTestObservation struct {
// Resource data plane URI.
DataPlaneURI *string `json:"dataPlaneUri,omitempty" tf:"data_plane_uri,omitempty"`
// Description of the resource. Changing this forces a new Load Test to be created.
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// An encryption block as defined below. Changing this forces a new Load Test to be created.
Encryption *EncryptionObservation `json:"encryption,omitempty" tf:"encryption,omitempty"`
// The ID of the Load Test.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// An identity block as defined below. Specifies the Managed Identity which should be assigned to this Load Test.
Identity []LoadTestIdentityObservation `json:"identity,omitempty" tf:"identity,omitempty"`
// The Azure Region where the Load Test should exist. Changing this forces a new Load Test to be created.
Location *string `json:"location,omitempty" tf:"location,omitempty"`
// Specifies the name of the Resource Group within which this Load Test should exist. Changing this forces a new Load Test to be created.
ResourceGroupName *string `json:"resourceGroupName,omitempty" tf:"resource_group_name,omitempty"`
// A mapping of tags which should be assigned to the Load Test.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*LoadTestObservation) DeepCopy ¶
func (in *LoadTestObservation) DeepCopy() *LoadTestObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestObservation.
func (*LoadTestObservation) DeepCopyInto ¶
func (in *LoadTestObservation) DeepCopyInto(out *LoadTestObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadTestParameters ¶
type LoadTestParameters struct {
// Description of the resource. Changing this forces a new Load Test to be created.
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// An encryption block as defined below. Changing this forces a new Load Test to be created.
// +kubebuilder:validation:Optional
Encryption *EncryptionParameters `json:"encryption,omitempty" tf:"encryption,omitempty"`
// An identity block as defined below. Specifies the Managed Identity which should be assigned to this Load Test.
// +kubebuilder:validation:Optional
Identity []LoadTestIdentityParameters `json:"identity,omitempty" tf:"identity,omitempty"`
// The Azure Region where the Load Test should exist. Changing this forces a new Load Test to be created.
// +kubebuilder:validation:Optional
Location *string `json:"location,omitempty" tf:"location,omitempty"`
// Specifies the name of the Resource Group within which this Load Test should exist. Changing this forces a new Load Test to be created.
// +crossplane:generate:reference:type=github.com/upbound/provider-azure/apis/azure/v1beta1.ResourceGroup
// +kubebuilder:validation:Optional
ResourceGroupName *string `json:"resourceGroupName,omitempty" tf:"resource_group_name,omitempty"`
// Reference to a ResourceGroup in azure to populate resourceGroupName.
// +kubebuilder:validation:Optional
ResourceGroupNameRef *v1.Reference `json:"resourceGroupNameRef,omitempty" tf:"-"`
// Selector for a ResourceGroup in azure to populate resourceGroupName.
// +kubebuilder:validation:Optional
ResourceGroupNameSelector *v1.Selector `json:"resourceGroupNameSelector,omitempty" tf:"-"`
// A mapping of tags which should be assigned to the Load Test.
// +kubebuilder:validation:Optional
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*LoadTestParameters) DeepCopy ¶
func (in *LoadTestParameters) DeepCopy() *LoadTestParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestParameters.
func (*LoadTestParameters) DeepCopyInto ¶
func (in *LoadTestParameters) DeepCopyInto(out *LoadTestParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadTestSpec ¶
type LoadTestSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider LoadTestParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider LoadTestInitParameters `json:"initProvider,omitempty"`
}
LoadTestSpec defines the desired state of LoadTest
func (*LoadTestSpec) DeepCopy ¶
func (in *LoadTestSpec) DeepCopy() *LoadTestSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestSpec.
func (*LoadTestSpec) DeepCopyInto ¶
func (in *LoadTestSpec) DeepCopyInto(out *LoadTestSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadTestStatus ¶
type LoadTestStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider LoadTestObservation `json:"atProvider,omitempty"`
}
LoadTestStatus defines the observed state of LoadTest.
func (*LoadTestStatus) DeepCopy ¶
func (in *LoadTestStatus) DeepCopy() *LoadTestStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadTestStatus.
func (*LoadTestStatus) DeepCopyInto ¶
func (in *LoadTestStatus) DeepCopyInto(out *LoadTestStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.