Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=storagepool.azure.upbound.io +versionName=v1beta1
Index ¶
- Constants
- Variables
- type DiskPool
- func (in *DiskPool) DeepCopy() *DiskPool
- func (in *DiskPool) DeepCopyInto(out *DiskPool)
- func (in *DiskPool) DeepCopyObject() runtime.Object
- func (mg *DiskPool) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *DiskPool) GetConnectionDetailsMapping() map[string]string
- func (mg *DiskPool) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *DiskPool) GetID() string
- func (tr *DiskPool) GetInitParameters() (map[string]any, error)
- func (mg *DiskPool) GetManagementPolicies() xpv1.ManagementPolicies
- func (tr *DiskPool) GetMergedParameters(shouldMergeInitProvider bool) (map[string]any, error)
- func (tr *DiskPool) GetObservation() (map[string]any, error)
- func (tr *DiskPool) GetParameters() (map[string]any, error)
- func (mg *DiskPool) GetProviderConfigReference() *xpv1.Reference
- func (mg *DiskPool) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *DiskPool) GetTerraformResourceType() string
- func (tr *DiskPool) GetTerraformSchemaVersion() int
- func (mg *DiskPool) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *DiskPool) Hub()
- func (tr *DiskPool) LateInitialize(attrs []byte) (bool, error)
- func (mg *DiskPool) ResolveReferences(ctx context.Context, c client.Reader) error
- func (mg *DiskPool) SetConditions(c ...xpv1.Condition)
- func (mg *DiskPool) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (mg *DiskPool) SetManagementPolicies(r xpv1.ManagementPolicies)
- func (tr *DiskPool) SetObservation(obs map[string]any) error
- func (tr *DiskPool) SetParameters(params map[string]any) error
- func (mg *DiskPool) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *DiskPool) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *DiskPool) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type DiskPoolInitParameters
- type DiskPoolList
- type DiskPoolObservation
- type DiskPoolParameters
- type DiskPoolSpec
- type DiskPoolStatus
Constants ¶
const ( CRDGroup = "storagepool.azure.upbound.io" CRDVersion = "v1beta1" )
Package type metadata.
Variables ¶
var ( DiskPool_Kind = "DiskPool" DiskPool_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: DiskPool_Kind}.String() DiskPool_KindAPIVersion = DiskPool_Kind + "." + CRDGroupVersion.String() DiskPool_GroupVersionKind = CRDGroupVersion.WithKind(DiskPool_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type DiskPool ¶
type DiskPool struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.location) || (has(self.initProvider) && has(self.initProvider.location))",message="spec.forProvider.location is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.skuName) || (has(self.initProvider) && has(self.initProvider.skuName))",message="spec.forProvider.skuName is a required parameter"
// +kubebuilder:validation:XValidation:rule="!('*' in self.managementPolicies || 'Create' in self.managementPolicies || 'Update' in self.managementPolicies) || has(self.forProvider.zones) || (has(self.initProvider) && has(self.initProvider.zones))",message="spec.forProvider.zones is a required parameter"
Spec DiskPoolSpec `json:"spec"`
Status DiskPoolStatus `json:"status,omitempty"`
}
DiskPool is the Schema for the DiskPools API. Manages a Disk Pool. +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,azure}
func (*DiskPool) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskPool.
func (*DiskPool) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DiskPool) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*DiskPool) GetCondition ¶
func (mg *DiskPool) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this DiskPool.
func (*DiskPool) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this DiskPool
func (*DiskPool) GetDeletionPolicy ¶
func (mg *DiskPool) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this DiskPool.
func (*DiskPool) GetInitParameters ¶ added in v0.35.0
GetInitParameters of this DiskPool
func (*DiskPool) GetManagementPolicies ¶ added in v0.35.0
func (mg *DiskPool) GetManagementPolicies() xpv1.ManagementPolicies
GetManagementPolicies of this DiskPool.
func (*DiskPool) GetMergedParameters ¶ added in v0.40.0
GetInitParameters of this DiskPool
func (*DiskPool) GetObservation ¶
GetObservation of this DiskPool
func (*DiskPool) GetParameters ¶
GetParameters of this DiskPool
func (*DiskPool) GetProviderConfigReference ¶
GetProviderConfigReference of this DiskPool.
func (*DiskPool) GetPublishConnectionDetailsTo ¶
func (mg *DiskPool) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this DiskPool.
func (*DiskPool) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this DiskPool
func (*DiskPool) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*DiskPool) GetWriteConnectionSecretToReference ¶
func (mg *DiskPool) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this DiskPool.
func (*DiskPool) Hub ¶ added in v0.42.1
func (tr *DiskPool) Hub()
Hub marks this type as a conversion hub.
func (*DiskPool) LateInitialize ¶
LateInitialize this DiskPool using its observed tfState. returns True if there are any spec changes for the resource.
func (*DiskPool) ResolveReferences ¶
func (*DiskPool) SetConditions ¶
SetConditions of this DiskPool.
func (*DiskPool) SetDeletionPolicy ¶
func (mg *DiskPool) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this DiskPool.
func (*DiskPool) SetManagementPolicies ¶ added in v0.35.0
func (mg *DiskPool) SetManagementPolicies(r xpv1.ManagementPolicies)
SetManagementPolicies of this DiskPool.
func (*DiskPool) SetObservation ¶
SetObservation for this DiskPool
func (*DiskPool) SetParameters ¶
SetParameters for this DiskPool
func (*DiskPool) SetProviderConfigReference ¶
SetProviderConfigReference of this DiskPool.
func (*DiskPool) SetPublishConnectionDetailsTo ¶
func (mg *DiskPool) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this DiskPool.
func (*DiskPool) SetWriteConnectionSecretToReference ¶
func (mg *DiskPool) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this DiskPool.
type DiskPoolInitParameters ¶ added in v0.35.0
type DiskPoolInitParameters struct {
// The Azure Region where the Disk Pool should exist. Changing this forces a new Disk Pool to be created.
Location *string `json:"location,omitempty" tf:"location,omitempty"`
// The SKU of the Disk Pool. Possible values are Basic_B1, Standard_S1 and Premium_P1. Changing this forces a new Disk Pool to be created.
SkuName *string `json:"skuName,omitempty" tf:"sku_name,omitempty"`
// The ID of the Subnet where the Disk Pool should be created. Changing this forces a new Disk Pool to be created.
// +crossplane:generate:reference:type=github.com/upbound/provider-azure/apis/network/v1beta2.Subnet
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractResourceID()
SubnetID *string `json:"subnetId,omitempty" tf:"subnet_id,omitempty"`
// Reference to a Subnet in network to populate subnetId.
// +kubebuilder:validation:Optional
SubnetIDRef *v1.Reference `json:"subnetIdRef,omitempty" tf:"-"`
// Selector for a Subnet in network to populate subnetId.
// +kubebuilder:validation:Optional
SubnetIDSelector *v1.Selector `json:"subnetIdSelector,omitempty" tf:"-"`
// A mapping of tags which should be assigned to the Disk Pool.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
// Specifies a list of Availability Zones in which this Disk Pool should be located. Changing this forces a new Disk Pool to be created.
// +listType=set
Zones []*string `json:"zones,omitempty" tf:"zones,omitempty"`
}
func (*DiskPoolInitParameters) DeepCopy ¶ added in v0.35.0
func (in *DiskPoolInitParameters) DeepCopy() *DiskPoolInitParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskPoolInitParameters.
func (*DiskPoolInitParameters) DeepCopyInto ¶ added in v0.35.0
func (in *DiskPoolInitParameters) DeepCopyInto(out *DiskPoolInitParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DiskPoolList ¶
type DiskPoolList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []DiskPool `json:"items"`
}
DiskPoolList contains a list of DiskPools
func (*DiskPoolList) DeepCopy ¶
func (in *DiskPoolList) DeepCopy() *DiskPoolList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskPoolList.
func (*DiskPoolList) DeepCopyInto ¶
func (in *DiskPoolList) DeepCopyInto(out *DiskPoolList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DiskPoolList) DeepCopyObject ¶
func (in *DiskPoolList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*DiskPoolList) GetItems ¶
func (l *DiskPoolList) GetItems() []resource.Managed
GetItems of this DiskPoolList.
type DiskPoolObservation ¶
type DiskPoolObservation struct {
// The ID of the Disk Pool.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// The Azure Region where the Disk Pool should exist. Changing this forces a new Disk Pool to be created.
Location *string `json:"location,omitempty" tf:"location,omitempty"`
// The name of the Resource Group where the Disk Pool should exist. Changing this forces a new Disk Pool to be created.
ResourceGroupName *string `json:"resourceGroupName,omitempty" tf:"resource_group_name,omitempty"`
// The SKU of the Disk Pool. Possible values are Basic_B1, Standard_S1 and Premium_P1. Changing this forces a new Disk Pool to be created.
SkuName *string `json:"skuName,omitempty" tf:"sku_name,omitempty"`
// The ID of the Subnet where the Disk Pool should be created. Changing this forces a new Disk Pool to be created.
SubnetID *string `json:"subnetId,omitempty" tf:"subnet_id,omitempty"`
// A mapping of tags which should be assigned to the Disk Pool.
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
// Specifies a list of Availability Zones in which this Disk Pool should be located. Changing this forces a new Disk Pool to be created.
// +listType=set
Zones []*string `json:"zones,omitempty" tf:"zones,omitempty"`
}
func (*DiskPoolObservation) DeepCopy ¶
func (in *DiskPoolObservation) DeepCopy() *DiskPoolObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskPoolObservation.
func (*DiskPoolObservation) DeepCopyInto ¶
func (in *DiskPoolObservation) DeepCopyInto(out *DiskPoolObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DiskPoolParameters ¶
type DiskPoolParameters struct {
// The Azure Region where the Disk Pool should exist. Changing this forces a new Disk Pool to be created.
// +kubebuilder:validation:Optional
Location *string `json:"location,omitempty" tf:"location,omitempty"`
// The name of the Resource Group where the Disk Pool should exist. Changing this forces a new Disk Pool to be created.
// +crossplane:generate:reference:type=github.com/upbound/provider-azure/apis/azure/v1beta1.ResourceGroup
// +kubebuilder:validation:Optional
ResourceGroupName *string `json:"resourceGroupName,omitempty" tf:"resource_group_name,omitempty"`
// Reference to a ResourceGroup in azure to populate resourceGroupName.
// +kubebuilder:validation:Optional
ResourceGroupNameRef *v1.Reference `json:"resourceGroupNameRef,omitempty" tf:"-"`
// Selector for a ResourceGroup in azure to populate resourceGroupName.
// +kubebuilder:validation:Optional
ResourceGroupNameSelector *v1.Selector `json:"resourceGroupNameSelector,omitempty" tf:"-"`
// The SKU of the Disk Pool. Possible values are Basic_B1, Standard_S1 and Premium_P1. Changing this forces a new Disk Pool to be created.
// +kubebuilder:validation:Optional
SkuName *string `json:"skuName,omitempty" tf:"sku_name,omitempty"`
// The ID of the Subnet where the Disk Pool should be created. Changing this forces a new Disk Pool to be created.
// +crossplane:generate:reference:type=github.com/upbound/provider-azure/apis/network/v1beta2.Subnet
// +crossplane:generate:reference:extractor=github.com/crossplane/upjet/pkg/resource.ExtractResourceID()
// +kubebuilder:validation:Optional
SubnetID *string `json:"subnetId,omitempty" tf:"subnet_id,omitempty"`
// Reference to a Subnet in network to populate subnetId.
// +kubebuilder:validation:Optional
SubnetIDRef *v1.Reference `json:"subnetIdRef,omitempty" tf:"-"`
// Selector for a Subnet in network to populate subnetId.
// +kubebuilder:validation:Optional
SubnetIDSelector *v1.Selector `json:"subnetIdSelector,omitempty" tf:"-"`
// A mapping of tags which should be assigned to the Disk Pool.
// +kubebuilder:validation:Optional
// +mapType=granular
Tags map[string]*string `json:"tags,omitempty" tf:"tags,omitempty"`
// Specifies a list of Availability Zones in which this Disk Pool should be located. Changing this forces a new Disk Pool to be created.
// +kubebuilder:validation:Optional
// +listType=set
Zones []*string `json:"zones,omitempty" tf:"zones,omitempty"`
}
func (*DiskPoolParameters) DeepCopy ¶
func (in *DiskPoolParameters) DeepCopy() *DiskPoolParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskPoolParameters.
func (*DiskPoolParameters) DeepCopyInto ¶
func (in *DiskPoolParameters) DeepCopyInto(out *DiskPoolParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DiskPoolSpec ¶
type DiskPoolSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider DiskPoolParameters `json:"forProvider"`
// THIS IS A BETA FIELD. It will be honored
// unless the Management Policies feature flag is disabled.
// InitProvider holds the same fields as ForProvider, with the exception
// of Identifier and other resource reference fields. The fields that are
// in InitProvider are merged into ForProvider when the resource is created.
// The same fields are also added to the terraform ignore_changes hook, to
// avoid updating them after creation. This is useful for fields that are
// required on creation, but we do not desire to update them after creation,
// for example because of an external controller is managing them, like an
// autoscaler.
InitProvider DiskPoolInitParameters `json:"initProvider,omitempty"`
}
DiskPoolSpec defines the desired state of DiskPool
func (*DiskPoolSpec) DeepCopy ¶
func (in *DiskPoolSpec) DeepCopy() *DiskPoolSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskPoolSpec.
func (*DiskPoolSpec) DeepCopyInto ¶
func (in *DiskPoolSpec) DeepCopyInto(out *DiskPoolSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DiskPoolStatus ¶
type DiskPoolStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider DiskPoolObservation `json:"atProvider,omitempty"`
}
DiskPoolStatus defines the observed state of DiskPool.
func (*DiskPoolStatus) DeepCopy ¶
func (in *DiskPoolStatus) DeepCopy() *DiskPoolStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DiskPoolStatus.
func (*DiskPoolStatus) DeepCopyInto ¶
func (in *DiskPoolStatus) DeepCopyInto(out *DiskPoolStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.